@@ -194,7 +194,8 @@ void print_plot(Nlm_IteM);
 #endif
 #ifdef WIN_MAC
 int crefpict(char *, PicHandle );
-extern void add_apropos(char *);
+extern void add_apropos(char *progname, Nlm_ActnProc my_show_apropos);
+extern void show_apropos_unrooted(Nlm_IteM item);
 extern char *mac_fname_to_roman(char *);
 #else
 void process_args(int *argc, char *argv[]);
@@ -359,7 +360,7 @@ FD_unrooted *create_win_unrooted(void)
   int width, height;
   
 #ifdef WIN_MAC
-add_apropos("unrooted");
+add_apropos("unrooted", show_apropos_unrooted);
 #endif
 Nlm_KeyboardView(process_keys);
 fdui->unrooted = win = Nlm_DocumentWindow(-50, -33, -3, -3, "Unrooted", 
@@ -373,7 +374,6 @@ place_menu = win;
 #define OPEN_LABEL      "Open        O"
 #define SAVE_PLOT_LABEL "Save Plot S"
 #define PRINT_LABEL     "Print        P"
-#define QUIT_LABEL      "Quit         Q"
 #define FIND_LABEL      "Find     F"
 #define AGAIN_LABEL     "Again  A"
 #define RESET_LABEL     "Reset  R"
@@ -396,7 +396,9 @@ place_menu = win;
 #ifdef MICRO
   Nlm_CommandItem(menu, PRINT_LABEL, print_plot);
 #endif
+#ifndef WIN_MAC
   Nlm_CommandItem(menu, QUIT_LABEL, exit_callback);
+#endif
   Nlm_Advance(place_menu);
   menu = Nlm_PulldownMenu(place_menu, "Edit"); 
 #if defined(WIN_MAC) || defined(WIN_MSWIN)
@@ -1003,8 +1005,9 @@ if( !doing_copy ) tree_draw_proc(fd_unrooted->tree_plot);
 }
 
 
-void init_tree(char *titre)
+void create_win_if_needed(char *titre)
 {
+strcpy(fname, titre);
 debut_arbre();
 set_tree_w_title(fd_unrooted->unrooted, titre, notu);
 tree_draw_proc(fd_unrooted->tree_plot);
